==> ssp-center-api-0.1.26-gy4-20171013.084609-1-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/RspManagerShieldStrategy.java <==
/**
 * Project Name:ssp-center-api
 * File Name:RspManagerShieldStrategy.java
 * Package Name:cn.com.duiba.tuia.ssp.center.api.dto
 * Date:2017年8月21日下午3:33:02
 * Copyright (c) 2017, duiba.com.cn All Rights Reserved.
 *
*/

package cn.com.duiba.tuia.ssp.center.api.dto;

import java.io.Serializable;
import java.util.List;

import org.apache.commons.lang.builder.ToStringBuilder;

/**
 * ClassName:RspManagerShieldStrategy <br/>
 * Function: 管理端屏蔽标签信息. <br/>
 * Date:     2017年8月21日 下午3:33:02 <br/>
 * @author   guyan
 * @version  
 * @since    JDK 1.6
 * @see 	 
 */
public class RspManagerShieldStrategy implements Serializable  {

    /**序列号*/
    private static final long serialVersionUID = -6151446921677622415L;
    
    /**管理端屏蔽策略标签ID*/
    private Long              managerStrategyId;
    
    /** 管理端屏蔽行业. */
    private List<TagLevel>    managerShieldIndustries;

    /** 管理端屏蔽广告主. */
    private List<String>      managerShieldAdvertisers;

    /** 管理端屏蔽广告列表. */
    private List<TagLevel>    managerAdvertTagNums;

    /** 管理端屏蔽活动标签列表 */
    private List<TagLevel>    managerShieldActivitys;

    /** 管理端是否屏蔽行业状态. */
    private boolean           managerIndustryFlag      = false;

    /** 管理端是否屏蔽广告主状态. */
    private boolean           managerAdvertiserFlag    = false;

    /** 管理端是否屏蔽广告状态. */
    private boolean           managerAdvertTagNumsFlag = false;
    
    /** 管理端是否屏蔽活动标签状态. */
    private boolean           managerActivitysFlag     = false;
    
    
    
    public Long getManagerStrategyId() {
        return managerStrategyId;
    }

    
    public void setManagerStrategyId(Long managerStrategyId) {
        this.managerStrategyId = managerStrategyId;
    }

    
    public List<TagLevel> getManagerShieldIndustries() {
        return managerShieldIndustries;
    }

    
    public void setManagerShieldIndustries(List<TagLevel> managerShieldIndustries) {
        this.managerShieldIndustries = managerShieldIndustries;
    }

    
    public List<String> getManagerShieldAdvertisers() {
        return managerShieldAdvertisers;
    }

    
    public void setManagerShieldAdvertisers(List<String> managerShieldAdvertisers) {
        this.managerShieldAdvertisers = managerShieldAdvertisers;
    }

    
    public List<TagLevel> getManagerAdvertTagNums() {
        return managerAdvertTagNums;
    }

    
    public void setManagerAdvertTagNums(List<TagLevel> managerAdvertTagNums) {
        this.managerAdvertTagNums = managerAdvertTagNums;
    }

    
    public List<TagLevel> getManagerShieldActivitys() {
        return managerShieldActivitys;
    }

    
    public void setManagerShieldActivitys(List<TagLevel> managerShieldActivitys) {
        this.managerShieldActivitys = managerShieldActivitys;
    }

    
    public boolean isManagerIndustryFlag() {
        return managerIndustryFlag;
    }

    
    public void setManagerIndustryFlag(boolean managerIndustryFlag) {
        this.managerIndustryFlag = managerIndustryFlag;
    }

    
    public boolean isManagerAdvertiserFlag() {
        return managerAdvertiserFlag;
    }

    
    public void setManagerAdvertiserFlag(boolean managerAdvertiserFlag) {
        this.managerAdvertiserFlag = managerAdvertiserFlag;
    }

    
    public boolean isManagerAdvertTagNumsFlag() {
        return managerAdvertTagNumsFlag;
    }

    
    public void setManagerAdvertTagNumsFlag(boolean managerAdvertTagNumsFlag) {
        this.managerAdvertTagNumsFlag = managerAdvertTagNumsFlag;
    }

    
    public boolean isManagerActivitysFlag() {
        return managerActivitysFlag;
    }

    
    public void setManagerActivitysFlag(boolean managerActivitysFlag) {
        this.managerActivitysFlag = managerActivitysFlag;
    }
    
    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }

}

==> ssp-center-api-0.2.7.gy3-20180110.054042-1-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/RspManagerShieldStrategy.java <==
/**
 * Project Name:ssp-center-api
 * File Name:RspManagerShieldStrategy.java
 * Package Name:cn.com.duiba.tuia.ssp.center.api.dto
 * Date:2017年8月21日下午3:33:02
 * Copyright (c) 2017, duiba.com.cn All Rights Reserved.
 *
*/

package cn.com.duiba.tuia.ssp.center.api.dto;

import java.io.Serializable;
import java.util.List;

import org.apache.commons.lang.builder.ToStringBuilder;

/**
 * ClassName:RspManagerShieldStrategy <br/>
 * Function: 管理端屏蔽标签信息. <br/>
 * Date:     2017年8月21日 下午3:33:02 <br/>
 * @author   guyan
 * @version  
 * @since    JDK 1.6
 * @see 	 
 */
public class RspManagerShieldStrategy implements Serializable  {

    /**序列号*/
    private static final long serialVersionUID = -6151446921677622415L;
    
    /**管理端屏蔽策略标签ID*/
    private Long              managerStrategyId;
    
    /** 管理端屏蔽行业. */
    private List<TagLevel>    managerShieldIndustries;
    /** 广告线 行业屏蔽标签（逗号分隔）**/
    private String advertIndustriesTag;
    /** 广告线与媒体并集 行业屏蔽标签（逗号分隔） **/
    private String industriesTags;

    /** 管理端屏蔽广告主. */
    private List<String>      managerShieldAdvertisers;

    /** 管理端屏蔽广告列表. */
    private List<TagLevel>    managerAdvertTagNums;
    /** 广告线 广告屏蔽标签（逗号分隔） **/
    private String advertSlotTag;
    /** 广告线与媒体并集 广告屏蔽标签（逗号分隔） **/
    private String slotTags;

    /** 管理端屏蔽活动标签列表 */
    private List<TagLevel>    managerShieldActivitys;

    /** 管理端是否屏蔽行业状态. */
    private boolean           managerIndustryFlag      = false;

    /** 管理端是否屏蔽广告主状态. */
    private boolean           managerAdvertiserFlag    = false;

    /** 管理端是否屏蔽广告状态. */
    private boolean           managerAdvertTagNumsFlag = false;
    
    /** 管理端是否屏蔽活动标签状态. */
    private boolean           managerActivitysFlag     = false;
    
    
    
    public Long getManagerStrategyId() {
        return managerStrategyId;
    }

    
    public void setManagerStrategyId(Long managerStrategyId) {
        this.managerStrategyId = managerStrategyId;
    }

    
    public List<TagLevel> getManagerShieldIndustries() {
        return managerShieldIndustries;
    }

    
    public void setManagerShieldIndustries(List<TagLevel> managerShieldIndustries) {
        this.managerShieldIndustries = managerShieldIndustries;
    }

    
    public List<String> getManagerShieldAdvertisers() {
        return managerShieldAdvertisers;
    }

    
    public void setManagerShieldAdvertisers(List<String> managerShieldAdvertisers) {
        this.managerShieldAdvertisers = managerShieldAdvertisers;
    }

    
    public List<TagLevel> getManagerAdvertTagNums() {
        return managerAdvertTagNums;
    }

    
    public void setManagerAdvertTagNums(List<TagLevel> managerAdvertTagNums) {
        this.managerAdvertTagNums = managerAdvertTagNums;
    }

    
    public List<TagLevel> getManagerShieldActivitys() {
        return managerShieldActivitys;
    }

    
    public void setManagerShieldActivitys(List<TagLevel> managerShieldActivitys) {
        this.managerShieldActivitys = managerShieldActivitys;
    }

    
    public boolean isManagerIndustryFlag() {
        return managerIndustryFlag;
    }

    
    public void setManagerIndustryFlag(boolean managerIndustryFlag) {
        this.managerIndustryFlag = managerIndustryFlag;
    }

    
    public boolean isManagerAdvertiserFlag() {
        return managerAdvertiserFlag;
    }

    
    public void setManagerAdvertiserFlag(boolean managerAdvertiserFlag) {
        this.managerAdvertiserFlag = managerAdvertiserFlag;
    }

    
    public boolean isManagerAdvertTagNumsFlag() {
        return managerAdvertTagNumsFlag;
    }

    
    public void setManagerAdvertTagNumsFlag(boolean managerAdvertTagNumsFlag) {
        this.managerAdvertTagNumsFlag = managerAdvertTagNumsFlag;
    }

    
    public boolean isManagerActivitysFlag() {
        return managerActivitysFlag;
    }

    
    public void setManagerActivitysFlag(boolean managerActivitysFlag) {
        this.managerActivitysFlag = managerActivitysFlag;
    }

    public String getAdvertIndustriesTag() {
        return advertIndustriesTag;
    }

    public void setAdvertIndustriesTag(String advertIndustriesTag) {
        this.advertIndustriesTag = advertIndustriesTag;
    }

    public String getIndustriesTags() {
        return industriesTags;
    }

    public void setIndustriesTags(String industriesTags) {
        this.industriesTags = industriesTags;
    }

    public String getSlotTags() {
        return slotTags;
    }

    public void setSlotTags(String slotTags) {
        this.slotTags = slotTags;
    }

    public String getAdvertSlotTag() {
        return advertSlotTag;
    }

    public void setAdvertSlotTag(String advertSlotTag) {
        this.advertSlotTag = advertSlotTag;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }

}
